# Probability Distribution Functions package
Probability Distribution Functions is a Python package to help in different kind of probability distributions for a Data Scientist. Probability distributions are a must know for a Data Scientist. It makes math easier for all the variables in a Data to help the model learn faster and get better accuracy. Different kinds of Probability DIstributions helps in different kinds of problems, datasets and models. For now this packages only consists of Gaussian/Normal Distribution and  Binomial Distribution more will be added later.
# Installation
To install published releases from PyPi execute:
```bash
 pip install probability-distributions-functions
```
To update visualkeras to the latest version, add the --upgrade flag to the above commands.
```bash
pip install --upgrade probability-distributions-functions
```
# Example
You can find the example on how to use the package [here](https://github.com/Moddy2024/Probability-Distribution-Functions). In the examples section of this repository.